==> simplenotewidget_0.1-13.tar.gz: simplenotewidget-0.1/src/main.cpp <==
#include <QtGui/QApplication>
#include <QtGui>
#include "mainwindow.h"


#ifdef Q_WS_HILDON
//Q_WS_MAEMO_5
  #include <QHBoxLayout>
  #include <X11/extensions/Xrender.h>
#endif


int main(int argc, char *argv[])
{
    QCoreApplication::setOrganizationName("Jan Bergmann");
    QCoreApplication::setApplicationName("simplenotewidget");


#ifdef Q_WS_HILDON

    qWarning("Please make sure you're running a composition manager!");
    bool  argbVisual=false;
     Display *dpy = XOpenDisplay(0); // open default display
     if (!dpy) {
         qWarning("Cannot connect to the X server");
         exit(1);
     }


     int screen = DefaultScreen(dpy);
     Colormap colormap = 0;
     Visual *visual = 0;
     int eventBase, errorBase;

     if (XRenderQueryExtension(dpy, &eventBase, &errorBase)) {
         int nvi;
         XVisualInfo templ;
         templ.screen  = screen;
         templ.depth   = 32;
         templ.c_class = TrueColor;
         XVisualInfo *xvi = XGetVisualInfo(dpy, VisualScreenMask |
                                           VisualDepthMask |
                                           VisualClassMask, &templ, &nvi);

         for (int i = 0; i < nvi; ++i) {
             XRenderPictFormat *format = XRenderFindVisualFormat(dpy,
                                                                 xvi[i].visual);
             if (format->type == PictTypeDirect && format->direct.alphaMask) {
                 visual = xvi[i].visual;
                 colormap = XCreateColormap(dpy, RootWindow(dpy, screen),
                                            visual, AllocNone);
                 argbVisual=true;
                 break;
             }
         }
     }
     if (argbVisual == true) {
         qWarning("Found ARGB visual. Starting app...");
     }
     else  {
         qWarning("Couldn't find ARGB visual... Exiting.");
     }

     QApplication app(dpy, argc, argv, Qt::HANDLE(visual), Qt::HANDLE(colormap));

#else
     QApplication app(argc, argv);
#endif


    MainWindow w;

    QSettings *oSettings;
    oSettings = new QSettings("janbergmann", "simplenotewidget");
    QColor cldefault = oSettings->value("bgcolor", QColor(255,255,0)).value<QColor>();
    int bgcoloralpha = oSettings->value("bgcoloralpha", int(200)).toInt();
    cldefault.setAlpha(bgcoloralpha);
    delete oSettings;


    //QColor cldefault = QColor(255,255,0);
    //cldefault.setAlpha(200);


    QPalette pal = w.palette();
    w.setAttribute(Qt::WA_TranslucentBackground);
    w.setAttribute(Qt::WA_NoSystemBackground, false);

    pal.setColor(QPalette::Window, cldefault);
    w.setPalette(pal);
    w.ensurePolished(); // workaround Oxygen filling the background
    w.setAttribute(Qt::WA_StyledBackground, false);


    w.resize(300, 180);
    w.show();
    return app.exec();
}

==> simplenotewidget_0.3-01.tar.gz: simplenotewidget-0.3/src/main.cpp <==
#include <QtGui/QApplication>
#include <QtGui>
#include "mainwindow.h"


#ifdef Q_WS_HILDON
//Q_WS_MAEMO_5
  #include <QHBoxLayout>
  #include <X11/extensions/Xrender.h>
#endif


int main(int argc, char *argv[])
{
    QCoreApplication::setOrganizationName("Jan Bergmann");
    QCoreApplication::setApplicationName("simplenotewidget");


#ifdef Q_WS_HILDON

    qWarning("Please make sure you're running a composition manager!");
    bool  argbVisual=false;
     Display *dpy = XOpenDisplay(0); // open default display
     if (!dpy) {
         qWarning("Cannot connect to the X server");
         exit(1);
     }


     int screen = DefaultScreen(dpy);
     Colormap colormap = 0;
     Visual *visual = 0;
     int eventBase, errorBase;

     if (XRenderQueryExtension(dpy, &eventBase, &errorBase)) {
         int nvi;
         XVisualInfo templ;
         templ.screen  = screen;
         templ.depth   = 32;
         templ.c_class = TrueColor;
         XVisualInfo *xvi = XGetVisualInfo(dpy, VisualScreenMask |
                                           VisualDepthMask |
                                           VisualClassMask, &templ, &nvi);

         for (int i = 0; i < nvi; ++i) {
             XRenderPictFormat *format = XRenderFindVisualFormat(dpy,
                                                                 xvi[i].visual);
             if (format->type == PictTypeDirect && format->direct.alphaMask) {
                 visual = xvi[i].visual;
                 colormap = XCreateColormap(dpy, RootWindow(dpy, screen), visual, AllocNone);
                 argbVisual=true;
                 break;
             }
         }
     }
     if (argbVisual == true) {
         qWarning("Found ARGB visual. Starting app...");
     }
     else  {
         qWarning("Couldn't find ARGB visual... Exiting.");
     }

     QApplication app(dpy, argc, argv, Qt::HANDLE(visual), Qt::HANDLE(colormap));

#else
     QApplication app(argc, argv);
#endif


    MainWindow w;

    QSettings *oSettings;
    oSettings = new QSettings("janbergmann", "simplenotewidget");
    QColor cldefault = oSettings->value("bgcolor", QColor(255,255,0)).value<QColor>();
    int bgcoloralpha = oSettings->value("bgcoloralpha", int(200)).toInt();
    cldefault.setAlpha(bgcoloralpha);
    //delete oSettings;


    QPalette pal = w.palette();
    w.setAttribute(Qt::WA_TranslucentBackground);
    w.setAttribute(Qt::WA_NoSystemBackground, false);

    pal.setColor(QPalette::Window, cldefault);
    w.setPalette(pal);
    w.ensurePolished();
    w.setAttribute(Qt::WA_StyledBackground, false);


    w.resize(300, 180);
    w.show();
    return app.exec();
}
